"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ApexParser_1 = require("../ApexParser");
const SyntaxErrorCounter_1 = require("./SyntaxErrorCounter");
test('testBasicQuery', () => {
    const [parser, errorCounter] = (0, SyntaxErrorCounter_1.createParser)("test.sosl", "[Find 'something' RETURNING Account]");
    const context = parser.soslLiteral();
    expect(context).toBeInstanceOf(ApexParser_1.SoslLiteralContext);
    expect(errorCounter.getNumErrors()).toEqual(0);
});
test('testEmbeddedQuote', () => {
    const [parser, errorCounter] = (0, SyntaxErrorCounter_1.createParser)("test.sosl", "[Find 'some\\'thing' RETURNING Account]");
    const context = parser.soslLiteral();
    expect(context).toBeInstanceOf(ApexParser_1.SoslLiteralContext);
    expect(errorCounter.getNumErrors()).toEqual(0);
});
test('testBracesFail', () => {
    const [parser, errorCounter] = (0, SyntaxErrorCounter_1.createParser)("test.sosl", "[Find {something} RETURNING Account]");
    const context = parser.soslLiteral();
    expect(context).toBeInstanceOf(ApexParser_1.SoslLiteralContext);
    expect(errorCounter.getNumErrors()).toEqual(1);
});
test('testBracesOnAltFormat', () => {
    const [parser, errorCounter] = (0, SyntaxErrorCounter_1.createParser)("test.sosl", "[Find {something} RETURNING Account]");
    const context = parser.soslLiteralAlt();
    expect(context).toBeInstanceOf(ApexParser_1.SoslLiteralAltContext);
    expect(errorCounter.getNumErrors()).toEqual(0);
});
test('testQuotesFailOnAltFormat', () => {
    const [parser, errorCounter] = (0, SyntaxErrorCounter_1.createParser)("test.sosl", "[Find 'something' RETURNING Account]");
    const context = parser.soslLiteralAlt();
    expect(context).toBeInstanceOf(ApexParser_1.SoslLiteralAltContext);
    expect(errorCounter.getNumErrors()).toEqual(1);
});
//# sourceMappingURL=SOSLParserTest.js.map