"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createParser = exports.SyntaxErrorCounter = void 0;
const antlr4ts_1 = require("antlr4ts");
const ApexLexer_1 = require("../ApexLexer");
const ApexParser_1 = require("../ApexParser");
const CaseInsensitiveInputStream_1 = require("../CaseInsensitiveInputStream");
class SyntaxErrorCounter {
    constructor() {
        this.numErrors = 0;
    }
    syntaxError(recognizer, offendingSymbol, line, charPositionInLine, msg, e) {
        this.numErrors += 1;
    }
    getNumErrors() {
        return this.numErrors;
    }
}
exports.SyntaxErrorCounter = SyntaxErrorCounter;
function createParser(userData, input) {
    const lexer = new ApexLexer_1.ApexLexer(new CaseInsensitiveInputStream_1.CaseInsensitiveInputStream(userData, input));
    const tokens = new antlr4ts_1.CommonTokenStream(lexer);
    const parser = new ApexParser_1.ApexParser(tokens);
    parser.removeErrorListeners();
    const errorCounter = new SyntaxErrorCounter();
    parser.addErrorListener(errorCounter);
    return [parser, errorCounter];
}
exports.createParser = createParser;
//# sourceMappingURL=SyntaxErrorCounter.js.map